TaskInfo class

A monitor's view of a single task, folded from its lifecycle events.

Constructors

TaskInfo({required String id, required String name})

Properties

args Object?
getter/setter pair
error String?
getter/setter pair
finishedAt DateTime?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id String
final
kwargs Object?
getter/setter pair
maxRetries int
getter/setter pair
name String
getter/setter pair
queue String?
getter/setter pair
receivedAt DateTime?
getter/setter pair
result Object?
getter/setter pair
retries int
getter/setter pair
runtimeMs int?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sentAt DateTime?
getter/setter pair
startedAt DateTime?
getter/setter pair
state TaskState
getter/setter pair
updatedAt DateTime
Last time any event touched this task — used for recency ordering.
getter/setter pair
workerId String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited