WorkerInfo class
A monitor's view of a worker process, folded from its heartbeats.
Constructors
- WorkerInfo({required String id})
Properties
- active ↔ int
-
getter/setter pair
- concurrency ↔ int
-
getter/setter pair
- failed ↔ int
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- hostname ↔ String?
-
getter/setter pair
- id → String
-
final
- lastHeartbeat ↔ DateTime
-
getter/setter pair
- online ↔ bool
-
False once
workerOfflineis seen or heartbeats lapse (see isAlive).getter/setter pair -
queues
↔ List<
String> -
getter/setter pair
- retried ↔ int
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- succeeded ↔ int
-
getter/setter pair
Methods
-
isAlive(
DateTime now, Duration timeout) → bool -
A worker counts as alive if it hasn't signed off and its last heartbeat
is within
timeoutofnow. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
{DateTime? now, Duration? timeout, List< String> ? activeTaskIds}) → Map<String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited